@@ -156,7 +156,7 @@ class ContextMixIn():
         else:
             # Do not use inspect.getsourcelines because it appears
             # to fail on some systems
-            lines = open(self._start.filename,encoding='utf-8').readlines()
+            lines = open(self._start.filename, encoding='utf-8').readlines()
             withlines = lines[self._start.lineno - 1 : end.lineno]
 
         withsource = textwrap.dedent(''.join(withlines))
@@ -254,7 +254,7 @@ class _Analyzer(ast.NodeVisitor):
 
 class GuiettaProperty:
     '''Holds the get/set methods for a Guietta magic property.
-    
+
     Initialize with two callables, *get* and *set()*::
 
         get() - returns the property value
@@ -262,12 +262,13 @@ class GuiettaProperty:
 
     *widget* must be a reference to the widget for which the property is
     being set.
-    
+
     The *set()* method is automatically decorated with
     `guietta.execute_in_main_thread` and `guietta.undo_context_manager`.
     Set *add_decorators* to False to avoid this. In this case, the
     *widget* parameter is ignored.
     '''
+
     def __init__(self, get, set, widget, add_decorators=True):
         try:
             assert(callable(get))
@@ -275,7 +276,7 @@ class GuiettaProperty:
         except AssertionError as e:
             errmsg = 'get and set must be two Python callables'
             raise TypeError(errmsg) from e
-            
+
         self.get = get
         if add_decorators:
             gui = widget._gui
@@ -341,19 +342,19 @@ def undo_context_manager(get_func):
     Modify the decorated function so that it returns a context manager that,
     when exiting, restores the previous widget state (saved
     calling *get_func*)::
-        
+
         def get_label()
             return gui.label
 
         @undo_context_manager(get_label):
         def set_label(value):
             gui.label = value
-            
+
     then later in the program::
-        
+
         with set_label(value):
             ...
-    
+
     upon exiting the *with* block, the label text will revert to its
     previous value.
     '''
@@ -378,11 +379,11 @@ def undo_context_manager(get_func):
 
 def execute_in_main_thread(gui):
     '''Decorator that makes sure that GUI methods run in the main thread.
-    
+
     QT restricts GUI updates to the main thread (that is, the thread that
     created the GUI). In order to allow updating
     the GUI from other threads, any function that does so can be decorated::
-        
+
         @execute_in_main_thread(gui)
         def myfunc(gui, widget, text):
            widget.setText(text)
@@ -391,7 +392,7 @@ def execute_in_main_thread(gui):
     main GUI thread, wraps the function call into a QT event that will
     be eventually received and processed by the main GUI thread. Otherwise,
     the function is executed immediately.
-    
+
     All guietta magic properties already use this decorator, so all GUI
     updates are automatically executed in the main GUI thread.
     '''
@@ -460,7 +461,6 @@ def _title_property(widget):
 
     @_alsoAcceptAnotherGui(widget)
     def set_title(title):
-        print('set_title')
         widget.setTitle(str(title))
 
     return GuiettaProperty(get_title, set_title, widget)
@@ -623,6 +623,42 @@ class HeartBeat(SmartQLabel):
         return _setonly_text_property(self)
 
 
+class Led(QLabel):
+    '''Led class
+
+    A label that changes foreground color between two possible values,
+    initialized by default with a small square with the foreground color.
+    Can be assigned a boolean to switch state.
+    '''
+    def __init__(self, offcolor='red', oncolor='green', text='<html>&#9635;</html>'):
+        self._offcolor = offcolor
+        self._oncolor = oncolor
+        self._state = None
+        super().__init__(text)
+        self.off()
+
+    def on(self):
+        self.setStyleSheet('QLabel { color: '+self._oncolor+' }')
+        self._state = False
+
+    def off(self):
+        self.setStyleSheet('QLabel { color: '+self._offcolor+' }')
+        self._state = True
+
+    def __guietta_property__(self):
+
+        def get_state():
+            return self._state
+
+        def set_state(state):
+            if state:
+                self.on()
+            else:
+                self.off()
+
+        return GuiettaProperty(get_state, set_state, self)
+
+
 def _guietta_property(widget):
     '''Create the instance property corresponding to `widget`'''
 
@@ -981,11 +1017,11 @@ class _ValueSlider(_CombinedWidget):
     '''A slider combined with an inputbox for the value.'''
 
     def __init__(self, orientation,
-                      name,
-                      anchor,
-                      myrange=None,
-                      unit='',
-                      default=None):
+                 name,
+                 anchor,
+                 myrange=None,
+                 unit='',
+                 default=None):
 
         if myrange is None:
             myrange = range(0, 100, 1)
@@ -1042,9 +1078,9 @@ class _ValueSlider(_CombinedWidget):
         slider_name = (self.slider, self.name)
 
         if self.anchor in [Qt.AnchorLeft, Qt.AnchorTop]:
-            first, last = self.editbox, slider_name
+            first, last = (self.editbox, self.name+'_editbox'), slider_name
         else:
-            first, last = slider_name, self.editbox
+            first, last = slider_name, (self.editbox, self.name+'_editbox')
 
         if self.slider.orientation() == Qt.Horizontal:
             ncols = len(rows[row])
@@ -1081,7 +1117,7 @@ class HValueSlider(_ValueSlider):
     '''A slider combined with an inputbox for the value.'''
 
     def __init__(self, name, myrange=None, unit='',
-                       anchor=Qt.AnchorRight, default=None):
+                 anchor=Qt.AnchorRight, default=None):
 
         super().__init__(Qt.Horizontal, name, anchor, myrange, unit, default)
 
@@ -1090,7 +1126,7 @@ class VValueSlider(_ValueSlider):
     '''A slider combined with an inputbox for the value.'''
 
     def __init__(self, name, myrange=None, unit='',
-                       anchor=Qt.AnchorBottom, default=None):
+                 anchor=Qt.AnchorBottom, default=None):
 
         super().__init__(Qt.Vertical, name, anchor, myrange, unit, default)
 
@@ -1162,7 +1198,7 @@ def _exception_handler(e, gui):
 
     elif mode == Exceptions.POPUP:
         QMessageBox.warning(None, "Error", "%s\n%s" %
-                           (e.__class__.__name__, str(e)))
+                            (e.__class__.__name__, str(e)))
     elif callable(mode):
         mode()
 
@@ -1170,6 +1206,7 @@ def _exception_handler(e, gui):
         raise TypeError('Exception mode must be either an instance of '
                         'the Exceptions enum or a callable handler.')
 
+
 def _exception_wrapper(func, gui):
     '''
     Wraps *func* with the default exception handler, based
@@ -1205,8 +1242,8 @@ def Ax(widget):
     except AttributeError as e:
         raise AttributeError('Class %s does not have an ''ax'' attribute.\n'
                       'Are you sure that you are referencing the correct plot?'
-                       %  widget.__class__.__name__) from e
-        
+                       % widget.__class__.__name__) from e
+
     # hack to remove all colorbars, in order to restore the ax geometry:
     # creating a colorbar will resize the ax, and creating a new one
     # will resize it further, unless the previous one has been removed.
@@ -1218,7 +1255,7 @@ def Ax(widget):
 
     yield ax
 
-    for k,v in widget.kwargs.items():
+    for k, v in widget.kwargs.items():
         getattr(widget.ax, k).__call__(v)
     ax.figure.canvas.draw()
 
@@ -1230,11 +1267,11 @@ class M(_DeferredCreationWidget):
     calls every time the Ax decorator is used. For example, adding the
     argument `set_ylabel='foo'`, will result in this function call:
     `ax.set_ylabel('foo')`
-    
+
     Creating an object of this class will import the matplotlib module.
     '''
     def __init__(self, name, width=5, height=3, dpi=100,
-                       subplots=(1,1), animated=False, **kwargs):
+                 subplots=(1, 1), animated=False, **kwargs):
 
         self._name = name
         self._width = width
@@ -1263,17 +1300,17 @@ class MA(M):
     update the display without redrawing the entire widget.
     '''
     def __init__(self, name, width=5, height=3, dpi=100,
-                       subplots=(1,1), **kwargs):
+                 subplots=(1,1), **kwargs):
         super().__init__(name, width, height, dpi, subplots, animated=True, **kwargs)
 
 
 class PG(_DeferredCreationWidget):
     '''A pyqtgraph PlotWidget.
-    
+
     Creating an object of this class will import the pyqtgraph module.'''
 
     _pyqtgraph_imported = False
-    
+
     def __init__(self, name, **kwargs):
 
         self._name = name
@@ -1281,13 +1318,13 @@ class PG(_DeferredCreationWidget):
 
     def create(self, gui):
         from guietta import guietta_pyqtgraph
-        widget =  guietta_pyqtgraph.PyQtGraphPlotWidget(**self._kwargs)
+        widget = guietta_pyqtgraph.PyQtGraphPlotWidget(**self._kwargs)
         return (widget, self._name)
-      
+
 
 class PGI(_DeferredCreationWidget):
     '''A pyqtgraph ImageView.
-    
+
       Creating an object of this class will import the pyqtgraph module.'''
 
     def __init__(self, name, **kwargs):
@@ -1296,7 +1333,7 @@ class PGI(_DeferredCreationWidget):
 
     def create(self, gui):
         from guietta import guietta_pyqtgraph
-        widget =  guietta_pyqtgraph.PyQtGraphImageView(**self._kwargs)
+        widget = guietta_pyqtgraph.PyQtGraphImageView(**self._kwargs)
         return (widget, self._name)
 
 
@@ -1425,6 +1462,7 @@ def _process_slots(x):
     else:
         raise ValueError('Element %s is not a valid slot assignment' % x)
 
+
 def _process_font(x):
     '''Normalize font assignments.
 
@@ -1458,6 +1496,7 @@ def _process_font(x):
     else:
         raise TypeError('Element %s is not a valid font specification' % x)
 
+
 def _check_string(x):
     if not isinstance(x, str) and x not in _specials:
         raise TypeError('Element %s is not a string' % str(x))
@@ -1922,7 +1961,7 @@ class Gui:
         self._guietta_properties.clear()
         if not self._create_properties:
             return
-        
+
         for name, widget in self._widgets.items():
             if hasattr(widget, '__guietta_property__'):
                 prop = widget.__guietta_property__()
@@ -1937,7 +1976,7 @@ class Gui:
                         errmsg = ('__guietta_property__() must return '
                                   'a tuple with two callables')
                         raise TypeError(errmsg) from e
-                        
+
                     prop = GuiettaProperty(get, set, widget)
             else:
                 prop = _guietta_property(widget)
@@ -2018,14 +2057,14 @@ class Gui:
 
     def row_stretch(self, *lists):
         '''Defines the row stretches
-        
+
         Arguments are lists as in the initializer. Since typically all
         rows have the same stretch, it is allowed to define just one or only
         a few rows in this method.
 
         Every element in the lists must be a number, that will be passed to the
         setRowStretch() QT function, or _ if no particular stretch is desired.
-        '''        
+        '''
         rows = Rows(lists)
         rows.check_same(self._rows, allow_less_rows=True)
 
@@ -2077,7 +2116,7 @@ class Gui:
         rows.map_in_place(_process_slots)
 
         for i, j, pair in rows.enumerate():
-            item = self[i,j]
+            item = self[i, j]
             signal_name, slot = pair
             connect(item, signal_name, slot)
 
@@ -2108,7 +2147,7 @@ class Gui:
         rows.map_in_place(_process_font)
 
         for i, j, font_spec in rows.enumerate():
-            self[i,j].setFont(font_spec)
+            self[i, j].setFont(font_spec)
 
     def rename(self, *lists):
         '''Overrides the default widget names.
@@ -2129,7 +2168,7 @@ class Gui:
         names_by_widget = {v: k for k, v in self._widgets.items()}
 
         for i, j, new_name in rows.enumerate():
-            widget = self[i,j]
+            widget = self[i, j]
             old_name = names_by_widget[widget]
 
             self._widgets[new_name] = self._widgets[old_name]
@@ -2139,7 +2178,7 @@ class Gui:
 
     def timer_start(self, callback, interval=1.0):
         '''Set up a timer to call *callback* every *interval* seconds.
-        
+
         The callback will receive the Gui instance as its only argument.
         '''
         self._timer = QTimer()
@@ -2167,7 +2206,7 @@ class Gui:
             self.timer_start(func, interval)
             return func
         return decorator
-        
+
     def __getitem__(self, name):
         '''Widget by coordinates [row,col]'''
         return self._layout.itemAtPosition(name[0], name[1]).widget()
@@ -2322,7 +2361,7 @@ class Gui:
     def title(self, title):
         '''Sets the window title'''
         self.window().setWindowTitle(title)
-        
+
     def execute_in_main_thread(self, f, *args):
         '''Make sure that f(args) is executed in the main GUI thread.
 
@@ -2337,6 +2376,7 @@ class Gui:
             f(*args)
         else:
             app = QApplication.instance()
+            app.customEvent = _customEvent
             app.postEvent(app, _result_event(QEvent.User, f, args))
 
     def execute_in_background(self, func, args=(), callback=None):
@@ -2423,6 +2463,39 @@ class Gui:
         subgui._exception_mode = self._exception_mode
         self._subguis_to_setup.append(subgui)
 
+    def group(self, name, get_list, set_list=None, map_on_get=None):
+        '''
+        Groups widgets in *get_list* so that they can be read in a single
+        instruction returning a namedtuple where each field has the corresponding widget name.
+        When assigning an iterable to the group, the widgets in *set_list*
+        are assigned to. If *set_list* is None, the same list as *get_list* is used.
+        Uses a *namedtuple* under the hood so the lists can be formatted like
+        in the namedtuple constructor.
+        '''
+        if set_list is None:
+            set_list = get_list
+
+        if map_on_get is None:
+            map_on_get = lambda x: x
+
+        class WidgetGroup():
+            def __init__(self, gui, get_list, set_list):
+                self.get_tuple = namedtuple('WidgetGroup', get_list)
+                self.set_tuple = namedtuple('WidgetGroup', set_list)
+                self._gui = gui
+
+            def __guietta_property__(self):
+                def get():
+                    values = [self._gui.proxy(name).get() for name in self.get_tuple._fields]
+                    return self.get_tuple(*map(map_on_get, values))
+                def set(xx):
+                    for name, x in zip(self.set_tuple._fields, xx):
+                        self._gui.proxy(name).set(x)
+                return GuiettaProperty(get, set, self)
+
+        self.widgets[name] = WidgetGroup(self, get_list, set_list)
+        self._align_guietta_properties()
+
 
 class GuiIterator():
     '''An iterator that allows looping over the GUI events:
@@ -2444,6 +2517,6 @@ class GuiIterator():
             return (name, event)
         else:
             raise StopIteration
-         
+
 
 # ___oOo___
